@@ -31,4 +31,28 @@ function (x, m = 4)
     return(result)
 }
 #obviously a direct copy of the promax function, with the addition of returning the angles between factors
-#based upon a suggestion to the R-help news group by Ulrich Keller and John Fox. 
\ No newline at end of file
+#based upon a suggestion to the R-help news group by Ulrich Keller and John Fox. 
+
+#added May 31st following suggestions to R-Help by Gunter Nickel
+"equamax" <- function(L, Tmat=diag(ncol(L)),  eps=1e-5, maxit=1000) {
+kappa=ncol(L)/(2*nrow(L))
+cfT(L, Tmat=diag(ncol(L)),  eps=eps, maxit=maxit)}
+
+
+#based completely on the GPArotation  GPForth function
+#modified to call the varimin function which is derived from the varimax function
+
+varimin <- function(L, Tmat = diag(ncol(L)), normalize = FALSE, eps = 1e-05, 
+    maxit = 1000) {
+    GPForth(A=L,Tmat = diag(ncol(L)), normalize = normalize, eps = eps, 
+    maxit = maxit, method = "varimin") }
+    
+ vgQ.varimin <- 
+function (L) 
+{
+    QL <- sweep(L^2, 2, colMeans(L^2), "-")
+    list(Gq = L * QL, f = sqrt(sum(diag(crossprod(QL))))^2/4, 
+        Method = "varimin")
+}
+   
+
