@@ -51,12 +51,13 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
      Phi <- NULL
       if(rotate != "none") {if (nfactors > 1) {
   
-   	if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" |rotate =="bifactor" ||rotate =="targetT" ) { 
+   	if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" |rotate =="bifactor"  |rotate =="varimin" |rotate =="targetT" |rotate =="equamax") { 
    	if (!require(GPArotation)) {stop("I am sorry, to do these rotations requires the GPArotation package to be installed")}
    	       #varimax is from the stats package, Varimax is from GPArotations
    	       colnames(loadings) <- paste("RC",1:nfactors,sep='')  #to remind us that we are rotating the components 
    			rotated <- do.call(rotate,list(loadings,...))
    			loadings <- rotated$loadings
+   			
    			 Phi <- NULL} else { 
    			
      			if ((rotate=="promax")|(rotate=="Promax") ) {pro <- Promax(loadings)
